import java.util.ArrayList;

/**
 * Repraesentiert eine Bank in der Banksimulation
 * @author Martin Ploetz
 *
 */
public class Bank {

	// Konstanten fr Name und BLZ
	final private String name;
	final private int blz;
	
	// Listen fr Kunden und Konten einer Bank
	private ArrayList<Kunde> kunden;
	private ArrayList<Girokonto> girokonten;
	private ArrayList<Sparkonto> sparkonten;
	
	/**
	 * Bank-Konstruktor
	 * @param name Name der Bank
	 * @param blz BLZ der Bank
	 */
	public Bank(String name, int blz){
		this.name = name;
		this.blz = blz;
		kunden = new ArrayList<Kunde>();
		girokonten = new ArrayList<Girokonto>();
		sparkonten = new ArrayList<Sparkonto>();
	}

	public String getName() {
		return name;
	}

	public int getBlz() {
		return blz;
	}
		
	/**
	 * legt einen neuen Kunden an und fuegt diesen der Bank hinzu
	 * @param name Name des neuen Kunden
	 */
	public void addNewCustomer(String name){
		Kunde kunde = new Kunde(name);
		kunden.add(kunde);
	}
		
	/**
	 * legt ein neues Girokonto an und fuegt es der Bank hinzu
	 * @param kontonr
	 * @param kunde
	 * @param bank
	 * @param dispo
	 */
	public void addNewGirokonto(int kontonr, Kunde kunde, Bank bank, double dispo){
		Girokonto konto = new Girokonto(kontonr, kunde, bank, dispo);
		girokonten.add(konto);
	}
	
	/**
	 * legt ein neues Sparkonto an und fuegt es der Bank hinzu
	 * @param kontonr
	 * @param kunde
	 * @param bank
	 * @param zinssatz
	 */
	public void addNewSparkonto(int kontonr, Kunde kunde, Bank bank, double zinssatz){
		Sparkonto konto = new Sparkonto(kontonr, kunde, bank, zinssatz);
		sparkonten.add(konto);
	}
	
	/**
	 * fuegt ein Girokonto einem Kunden hinzu
	 * @param konto
	 * @param kunde
	 */
	public void addGirokontoToCustomer(Girokonto konto, Kunde kunde){
		kunde.addGirokonto(konto);
	}
	
	/**
	 * fuegt ein Sparkonto einem Kunden hinzu
	 * @param konto
	 * @param kunde
	 */
	public void addGirokontoToCustomer(Sparkonto konto, Kunde kunde){
		kunde.addSparkonto(konto);
	}
	
	
}
